[ekiga] s/preferred/prefered



commit ca7a610235e2ebb4f3d4cd6a921575693d9cea7b
Author: Damien Sandras <dsandras seconix com>
Date:   Mon Dec 7 20:39:27 2009 +0100

    s/preferred/prefered

 .../components/local-roster/local-presentity.cpp   |   24 ++++++++++----------
 .../components/local-roster/local-presentity.h     |    6 ++--
 2 files changed, 15 insertions(+), 15 deletions(-)
---
diff --git a/lib/engine/components/local-roster/local-presentity.cpp b/lib/engine/components/local-roster/local-presentity.cpp
index a582725..b2d4a78 100644
--- a/lib/engine/components/local-roster/local-presentity.cpp
+++ b/lib/engine/components/local-roster/local-presentity.cpp
@@ -73,7 +73,7 @@ Local::Presentity::Presentity (Ekiga::ServiceCore &_core,
 {
   node = xmlNewNode (NULL, BAD_CAST "entry");
   xmlSetProp (node, BAD_CAST "uri", BAD_CAST uri.c_str ());
-  xmlSetProp (node, BAD_CAST "preferred", BAD_CAST "false");
+  xmlSetProp (node, BAD_CAST "prefered", BAD_CAST "false");
   xmlNewChild (node, NULL,
 	       BAD_CAST "name",
 	       BAD_CAST robust_xmlEscape (node->doc,
@@ -244,7 +244,7 @@ Local::Presentity::edit_presentity ()
 			   "element of ekiga's internal roster"));
   request->text ("name", _("Name:"), name);
   request->text ("uri", _("Address:"), uri);
-  request->boolean ("prefered", _("Is a prefered contact"), is_preferred ());
+  request->boolean ("prefered", _("Is a prefered contact"), is_prefered ());
 
   request->editable_set ("groups", _("Choose groups:"),
 			 groups, all_groups);
@@ -265,7 +265,7 @@ Local::Presentity::edit_presentity_form_submitted (bool submitted,
   const std::set<std::string> new_groups = result.editable_set ("groups");
   std::string new_uri = result.text ("uri");
   const std::string uri = get_uri ();
-  bool preferred = result.boolean ("preferred");
+  bool prefered = result.boolean ("prefered");
   std::set<xmlNodePtr> nodes_to_remove;
   size_t pos = new_uri.find_first_of (' ');
   if (pos != std::string::npos)
@@ -339,12 +339,12 @@ Local::Presentity::edit_presentity_form_submitted (bool submitted,
     }
   }
 
-  if (preferred) {
+  if (prefered) {
 
-    xmlSetProp (node, BAD_CAST "preferred", BAD_CAST "true");
+    xmlSetProp (node, BAD_CAST "prefered", BAD_CAST "true");
   } else {
 
-    xmlSetProp (node, BAD_CAST "preferred", BAD_CAST "false");
+    xmlSetProp (node, BAD_CAST "prefered", BAD_CAST "false");
   }
 
   updated ();
@@ -428,22 +428,22 @@ Local::Presentity::remove ()
 }
 
 bool
-Local::Presentity::is_preferred () const
+Local::Presentity::is_prefered () const
 {
-  bool preferred = false;
-  xmlChar* xml_str = xmlGetProp (node, (const xmlChar*)"preferred");
+  bool prefered = false;
+  xmlChar* xml_str = xmlGetProp (node, (const xmlChar*)"prefered");
 
   if (xml_str != NULL) {
 
     if (xmlStrEqual (xml_str, BAD_CAST "true")) {
 
-      preferred = true;
+      prefered = true;
     } else {
 
-      preferred = false;
+      prefered = false;
     }
     xmlFree (xml_str);
   }
 
-  return preferred;
+  return prefered;
 }
diff --git a/lib/engine/components/local-roster/local-presentity.h b/lib/engine/components/local-roster/local-presentity.h
index 481224d..835116f 100644
--- a/lib/engine/components/local-roster/local-presentity.h
+++ b/lib/engine/components/local-roster/local-presentity.h
@@ -132,11 +132,11 @@ namespace Local
     xmlNodePtr get_node () const;
 
 
     /** Tells if the contact is in the preferred list
      *
      * @return: Whether the contact is preferred
      */
-    bool is_preferred () const;
+    bool is_prefered () const;
 
     /** Rename the given group, if this Presentity belongs to it
      *
@@ -132,11 +132,11 @@ namespace Local
 
 
-    /** Tells if the contact is in the preferred list
+    /** Tells if the contact is in the prefered list
      *
@@ -132,11 +132,11 @@ namespace Local
      *
-     * @return: Whether the contact is preferred
+     * @return: Whether the contact is prefered
      */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]